exceptions.Exception

Module exceptions :: Class Exception |
[show private | hide private]
[frames | no frames]

## Type Exception

       object --+
                |
    BaseException --+
                    |
                   Exception

Known Subclasses:
  `DuplicateResourceError`

    Common base class for all non-exit exceptions.

Method Summary
| ``__init__`(...)` x.__init__(...) initializes x; see x.__class__.__doc__ for signature...
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T...
Inherited from BaseException
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name...
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name...
| ``__getitem__`(x, y)` x.__getitem__(y) <==> x[y]...
| ``__getslice__`(x, i, j)` Use of negative indices is not supported.
| ``__reduce__`(...)`
| ``__repr__`(x)` x.__repr__() <==> repr(x)...
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value...
| ``__setstate__`(...)`
| ``__str__`(x)` x.__str__() <==> str(x)...
Inherited from object
| ``__hash__`(x)` x.__hash__() <==> hash(x)...
| ``__reduce_ex__`(...)` helper for pickle...

Class Variable Summary
Inherited from BaseException
`getset_descriptor` | `args` = `<attribute 'args' of 'exceptions.BaseException' o...`
`member_descriptor` | `message` = `<member 'message' of 'exceptions.BaseException...`

Method Details

### __init__(...) (Constructor)
    x.__init__(...) initializes x; see x.__class__.__doc__ for signature
Overrides: `exceptions.BaseException.__init__`

### __new__(T, S, ...)
    T.__new__(S, ...) -> a new object with type S, a subtype of T
    Returns:
        a new object with type S, a subtype of T
Overrides: `exceptions.BaseException.__new__`

Generated by Epydoc 2.1 on Tue Sep 18 23:33:17 2007 | http://epydoc.sf.net